==> crontab-0.2.3.tgz: package/test/test.js <==
#!/usr/bin/env node

require('crontab').load(cronLoaded);

function cronLoaded(err, tab) {
    if (err) { console.log(err); process.exit(1); }
    
    var checkEmail   = '/usr/bin/env echo "check email"',
        haveFun      = '/usr/bin/env echo "hack node.js"',
        sleepLate    = '/usr/bin/env echo "wake up"',
        takeVacation = '/usr/bin/env echo "go to Bulgaria"',
        beSurprised  = '/usr/bin/env echo "get presents"',
        startServer  = '/usr/bin/env echo "starting some service..."';
    
    tab.removeAll(checkEmail);
    tab.removeAll(haveFun);
    tab.removeAll(sleepLate);
    tab.removeAll(takeVacation);
    tab.removeAll(beSurprised);
    tab.removeAll(startServer);
    
    var everyBusinessHour = tab.create(checkEmail);
    everyBusinessHour.minute().on(0);
    everyBusinessHour.hour().during(8, 17);
    everyBusinessHour.dow().during('mon', 'fri');
    
    var everyWeekDayNight = tab.create(haveFun);
    everyWeekDayNight.hour().during(19, 0);
    everyWeekDayNight.hour().during(0, 3);
    everyWeekDayNight.dow().during('mon', 'fri');

    var everyWeekEndMorning = tab.create(sleepLate);
    everyWeekEndMorning.minute().on(30);
    everyWeekEndMorning.hour().on(11);
    everyWeekEndMorning.dow().during('sat', 'sun');

    var everySummer = tab.create(takeVacation);
    everySummer.month().during('jun', 'sep');

    var everyChristmas = tab.create(beSurprised);
    everyChristmas.minute().on(30);
    everyChristmas.hour().on(9);
    everyChristmas.dom().on(24);
    everyChristmas.month().on('dec');

    var item = tab.create(startServer);
    item.everyReboot();
    
    tab.save(cronSaved);
}

function cronSaved(err, tab) {
    if (err) { console.log(err); process.exit(1); }
    
    console.log('saved');
}

==> crontab-0.2.5.tgz: package/test/test.js <==
#!/usr/bin/env node

require('../lib/index').load(cronLoaded);

function cronLoaded(err, tab) {
    if (err) { console.log(err); process.exit(1); }
    
    var uuid         = '74d967a0-120b-11e0-ac64-0800200c9a66',
        checkEmail   = '/usr/bin/env echo "check email"',
        haveFun      = '/usr/bin/env echo "hack node.js"',
        sleepLate    = '/usr/bin/env echo "wake up"',
        takeVacation = '/usr/bin/env echo "go to Bulgaria"',
        beSurprised  = '/usr/bin/env echo "get presents"',
        startServer  = '/usr/bin/env echo "starting some service" #' + uuid;
    
    tab.remove(tab.findCommand(checkEmail));
    tab.remove(tab.findCommand(haveFun));
    tab.remove(tab.findCommand(sleepLate));
    tab.remove(tab.findCommand(takeVacation));
    tab.remove(tab.findCommand(beSurprised));
    tab.remove(tab.findComment(uuid));
    
    var everyBusinessHour = tab.create(checkEmail);
    everyBusinessHour.minute().on(0);
    everyBusinessHour.hour().during(8, 17);
    everyBusinessHour.dow().during('mon', 'fri');
    
    var everyWeekDayNight = tab.create(haveFun);
    everyWeekDayNight.hour().during(19, 0);
    everyWeekDayNight.hour().during(0, 3);
    everyWeekDayNight.dow().during('mon', 'fri');

    var everyWeekEndMorning = tab.create(sleepLate);
    everyWeekEndMorning.minute().on(30);
    everyWeekEndMorning.hour().on(11);
    everyWeekEndMorning.dow().during('sat', 'sun');

    var everySummer = tab.create(takeVacation);
    everySummer.month().during('jun', 'sep');

    var everyChristmas = tab.create(beSurprised);
    everyChristmas.minute().on(30);
    everyChristmas.hour().on(9);
    everyChristmas.dom().on(24);
    everyChristmas.month().on('dec');

    var item = tab.create(startServer);
    item.everyReboot();
    
    tab.save(cronSaved);
}

function cronSaved(err, tab) {
    if (err) { console.log(err); process.exit(1); }
    
    console.log('saved');
}
